@@ -14,8 +14,8 @@ def acm():
     return Service("acm", listener=AwsApiListener("acm", MotoFallbackDispatcher(provider)))
 
 
-@aws_provider()
-def apigateway():
+@aws_provider(api="apigateway", name="default")
+def apigateway_legacy():
     from localstack.services.apigateway.provider import ApigatewayApiListener, ApigatewayProvider
 
     provider = ApigatewayProvider()
@@ -24,6 +24,16 @@ def apigateway():
     return Service("apigateway", listener=listener, lifecycle_hook=provider)
 
 
+@aws_provider(api="apigateway", name="asf")
+def apigateway_asf():
+    from localstack.services.apigateway.provider_asf import AsfApigatewayProvider
+
+    provider = AsfApigatewayProvider()
+    listener = AwsApiListener("apigateway", MotoFallbackDispatcher(provider))
+
+    return Service("apigateway", listener=listener, lifecycle_hook=provider)
+
+
 @aws_provider()
 def cloudformation():
     from localstack.services.cloudformation.provider import CloudformationProvider
@@ -285,7 +295,21 @@ def sns():
 
 @aws_provider()
 def sqs():
-    from localstack.services.sqs import sqs_listener, sqs_starter
+    from localstack.aws.proxy import AwsApiListener
+    from localstack.services import edge
+    from localstack.services.sqs import query_api
+    from localstack.services.sqs.provider import SqsProvider
+
+    query_api.register(edge.ROUTER)
+
+    provider = SqsProvider()
+
+    return Service("sqs", listener=AwsApiListener("sqs", provider), lifecycle_hook=provider)
+
+
+@aws_provider(api="sqs", name="legacy")
+def sqs_legacy():
+    from localstack.services.sqs.legacy import sqs_listener, sqs_starter
 
     return Service(
         "sqs",
@@ -295,16 +319,6 @@ def sqs():
     )
 
 
-@aws_provider(api="sqs", name="asf")
-def sqs_asf():
-    from localstack.aws.proxy import AwsApiListener
-    from localstack.services.sqs.provider import SqsProvider
-
-    provider = SqsProvider()
-
-    return Service("sqs", listener=AwsApiListener("sqs", provider), lifecycle_hook=provider)
-
-
 @aws_provider()
 def ssm():
     from localstack.services.moto import MotoFallbackDispatcher
